@@ -86,7 +86,7 @@
 #define KPARTS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KPARTS_NO_DEPRECATED
-#  define KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54e00
+#  define KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55200
 #endif
 #ifdef KPARTS_NO_DEPRECATED_WARNINGS
 #  define KPARTS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KPARTS_DEPRECATED_WARNINGS_SINCE KPARTS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KPARTS_DEPRECATED_WARNINGS_SINCE 0x54e00
+#    define KPARTS_DEPRECATED_WARNINGS_SINCE 0x55200
 #  endif
 #endif
 
@@ -145,10 +145,35 @@
 #else
 #  define KPARTS_DEPRECATED_VERSION_5_78(text)
 #endif
+
+#if KPARTS_DEPRECATED_WARNINGS_SINCE >= 0x55000
+#  define KPARTS_DEPRECATED_VERSION_5_80(text) KPARTS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KPARTS_DEPRECATED_VERSION_5_80(text)
+#endif
+
+#if KPARTS_DEPRECATED_WARNINGS_SINCE >= 0x55100
+#  define KPARTS_DEPRECATED_VERSION_5_81(text) KPARTS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KPARTS_DEPRECATED_VERSION_5_81(text)
+#endif
+
+#if KPARTS_DEPRECATED_WARNINGS_SINCE >= 0x55200
+#  define KPARTS_DEPRECATED_VERSION_5_82(text) KPARTS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KPARTS_DEPRECATED_VERSION_5_82(text)
+#endif
 #define KPARTS_DEPRECATED_VERSION_3(minor, text)      KPARTS_DEPRECATED_VERSION_3_##minor(text)
 #define KPARTS_DEPRECATED_VERSION_4(minor, text)      KPARTS_DEPRECATED_VERSION_4_##minor(text)
 #define KPARTS_DEPRECATED_VERSION_5(minor, text)      KPARTS_DEPRECATED_VERSION_5_##minor(text)
 #define KPARTS_DEPRECATED_VERSION(major, minor, text) KPARTS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KPARTS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KPARTS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
+#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
+#  define KPARTS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KPARTS_DEPRECATED_VERSION(major, minor, text)
+#  define KPARTS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KPARTS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#else
+#  define KPARTS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
+#  define KPARTS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#endif
 
 #endif /* KPARTS_EXPORT_H */
